<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl_NL">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Information on how to translate KeePassX can be found under:</source>
        <translation>U kunt informatie over het vertalen van KeePassX vinden op:</translation>
    </message>
    <message>
        <source>Team</source>
        <translation>Team</translation>
    </message>
    <message>
        <source>Developer, Project Admin</source>
        <translation>Ontwikkelaar, Projectleider</translation>
    </message>
    <message>
        <source>Web Designer</source>
        <translation>Web-ontwerper</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Ontwikkelaar</translation>
    </message>
    <message>
        <source>Thanks To</source>
        <translation>Met dank aan</translation>
    </message>
    <message>
        <source>Patches for better MacOS X support</source>
        <translation>Patches voor ondersteuning van MacOS X</translation>
    </message>
    <message>
        <source>Main Application Icon</source>
        <translation>Pictogram van de toepassing</translation>
    </message>
    <message>
        <source>Various fixes and improvements</source>
        <translation>Verscheidene verbeteringen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation>Kan bestand &apos;%1&apos; niet vinden.</translation>
    </message>
    <message>
        <source>Make sure that the program is installed correctly.</source>
        <translation>Controleer of de toepassing op de juiste wijze geïnstalleerd is.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Current Translation</source>
        <translation>Huidige vertaling</translation>
    </message>
    <message>
        <source>None</source>
        <comment>Please replace &apos;None&apos; with the language of your translation</comment>
        <translation>Nederlands</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Over KeePassX</translation>
    </message>
    <message>
        <source>AppName</source>
        <translation>AppName</translation>
    </message>
    <message>
        <source>AppFunc</source>
        <translation>AppFunc</translation>
    </message>
    <message>
        <source>http://keepassx.sourceforge.net</source>
        <translation>http://keepassx.sourceforge.net</translation>
    </message>
    <message>
        <source>keepassx@gmail.com</source>
        <translation>keepassx@gmail.com</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Bijdragen</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Vertaling</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <source>Copyright (C) 2005 - 2009 KeePassX Team
KeePassX is distributed under the terms of the
General Public License (GPL) version 2.</source>
        <translation>Copyright (C) 2005 - 2009 KeePassX Team
KeePassX wordt uitgegeven onder de voorwaarden
van de General Public License (GPL), versie 2.</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDlg</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Favoriet toevoegen</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Bestand:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Bladeren...</translation>
    </message>
    <message>
        <source>Edit Bookmark</source>
        <translation>Favoriet wijzigen</translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation>KeePass-databases (*.kdb)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
</context>
<context>
    <name>AutoTypeDlg</name>
    <message>
        <source>KeePassX - Auto-Type</source>
        <translation>KeePassX - Automatisch-invullen</translation>
    </message>
    <message>
        <source>Click on an entry to auto-type it.</source>
        <translation>Klik op een item om dit automatisch in te vullen.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Automatich invullen</translation>
    </message>
</context>
<context>
    <name>CDbSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>AES(Rijndael):  256 Bit   (default)</source>
        <translation>AES (Rijndael), 256 bits (standaard)</translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation>Twofish, 256 bits</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Please determine the number of encryption rounds.</source>
        <translation>Stel het aantal versleutelingsiteraties in.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is not valid integer value.</source>
        <translation>&apos;%1&apos; is geen geheel getal.</translation>
    </message>
    <message>
        <source>The number of encryption rounds have to be greater than 0.</source>
        <translation>Het aantal versleutelingsiteraties dient groter dan 0 te zijn.</translation>
    </message>
</context>
<context>
    <name>CEditEntryDlg</name>
    <message>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
    <message>
        <source>1 Week</source>
        <translation>1 week</translation>
    </message>
    <message>
        <source>2 Weeks</source>
        <translation>2 weken</translation>
    </message>
    <message>
        <source>3 Weeks</source>
        <translation>3 weken</translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation>1 maand</translation>
    </message>
    <message>
        <source>3 Months</source>
        <translation>3 maanden</translation>
    </message>
    <message>
        <source>6 Months</source>
        <translation>6 maanden</translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation>1 jaar</translation>
    </message>
    <message>
        <source>Calendar...</source>
        <translation>Kalender...</translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation>%1 Bits</translation>
    </message>
    <message>
        <source>Edit Entry</source>
        <translation>Item wijzigen</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Password and password repetition are not equal.
Please check your input.</source>
        <translation>Het ingevoerde wachtwoord komt niet overeen met
het bevestigde wachtwoord. Controleer uw invoer.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>[Untitled Entry]</source>
        <translation>[Naamloos]</translation>
    </message>
    <message>
        <source>Add Attachment...</source>
        <translation>Bijlage toevoegen...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Could not open file.</source>
        <translation>Kan bestand niet openen.</translation>
    </message>
    <message>
        <source>The chosen entry has no attachment or it is empty.</source>
        <translation>Het gekozen item heeft geen of een lege bijlage.</translation>
    </message>
    <message>
        <source>Save Attachment...</source>
        <translation>Bijlage opslaan...</translation>
    </message>
    <message>
        <source>Error while writing the file.</source>
        <translation>Fout bij het schrijven van het bestand.</translation>
    </message>
    <message>
        <source>Delete Attachment?</source>
        <translation>Bijlage verwijderen?</translation>
    </message>
    <message>
        <source>You are about to delete the attachment of this entry.
Are you sure?</source>
        <translation>Weet u zeker dat u de bijlage 
bij dit item wilt verwijderen?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No, Cancel</source>
        <translation>Nee, annuleren</translation>
    </message>
    <message>
        <source>New Entry</source>
        <translation>Nieuw item</translation>
    </message>
</context>
<context>
    <name>CGenPwDialog</name>
    <message>
        <source>Password Generator</source>
        <translation>Wachtwoordgenerator</translation>
    </message>
    <message>
        <source>%1 Bits</source>
        <translation>%1 Bits</translation>
    </message>
</context>
<context>
    <name>CSelectIconDlg</name>
    <message>
        <source>Replace...</source>
        <translation>Vervangen...</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Add Custom Icon</source>
        <translation>Nieuw pictogram toevoegen</translation>
    </message>
    <message>
        <source>Pick</source>
        <translation>Selecteren</translation>
    </message>
    <message>
        <source>Add Icons...</source>
        <translation>Pictogrammen toevoegen...</translation>
    </message>
    <message>
        <source>Images (%1)</source>
        <translation>Afbeeldingen (%1)</translation>
    </message>
    <message>
        <source>%1: File could not be loaded.</source>
        <translation>%1: Bestand kan niet worden geladen.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>An error occured while loading the icon(s):</source>
        <translation>Er is een fout opgetreden bij het laden van het pictogram:</translation>
    </message>
    <message>
        <source>An error occured while loading the icon.</source>
        <translation>Er is een fout opgetreden bij het laden van het pictogram.</translation>
    </message>
</context>
<context>
    <name>CSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <source>Select a directory...</source>
        <translation>Kies een map...</translation>
    </message>
    <message>
        <source>Select an executable...</source>
        <translation>Kies een uitvoerbaar bestand...</translation>
    </message>
    <message>
        <source>System Language</source>
        <translation>Taal volgens systeeminstellingen</translation>
    </message>
</context>
<context>
    <name>CalendarDialog</name>
    <message>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
</context>
<context>
    <name>CollectEntropyDlg</name>
    <message>
        <source>Random Number Generator</source>
        <translation>Toevalsgenerator</translation>
    </message>
    <message>
        <source>Collecting entropy...
Please move the mouse and/or press some keys until enought entropy for a reseed of the random number generator is collected.</source>
        <translation>Entropie wordt gegenereerd..
Verplaats de cursor van de muis en/of sla enkele toetsen op het toetsenbord aan totdat voldoende entropie is gegenereerd voor het initialiseren van de toevalsgenerator.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; color:#006400;&quot;&gt;Random pool successfully reseeded!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; color:#006400;&quot;&gt;Er is voldoende entropie gegenereerd voor het initiëren van de toevalsgenerator.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Entropy Collection</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CustomizeDetailViewDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Venster</translation>
    </message>
    <message>
        <source>Rich Text Editor</source>
        <translation>Tekstveld met opmaak (Rich Text)</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Vet</translation>
    </message>
    <message>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Cursief</translation>
    </message>
    <message>
        <source>I</source>
        <translation>I</translation>
    </message>
    <message>
        <source>Underlined</source>
        <translation>Onderstreept</translation>
    </message>
    <message>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <source>Left-Aligned</source>
        <translation>Links uitgelijnd</translation>
    </message>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Gecentreerd</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>Right-Aligned</source>
        <translation>Rechts uitgelijnd</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>Justified</source>
        <translation>Uitgevuld</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Tekstkleur</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Lettergrootte</translation>
    </message>
    <message>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <source>18</source>
        <translation>18</translation>
    </message>
    <message>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <source>26</source>
        <translation>26</translation>
    </message>
    <message>
        <source>28</source>
        <translation>28</translation>
    </message>
    <message>
        <source>36</source>
        <translation>36</translation>
    </message>
    <message>
        <source>42</source>
        <translation>42</translation>
    </message>
    <message>
        <source>78</source>
        <translation>78</translation>
    </message>
    <message>
        <source>Templates</source>
        <translation>Sjablonen</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>HTML</source>
        <translation>HTML</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Notities</translation>
    </message>
    <message>
        <source>Attachment Name</source>
        <translation>Naam bijlage</translation>
    </message>
    <message>
        <source>Creation Date</source>
        <translation>Aanmaakdatum</translation>
    </message>
    <message>
        <source>Last Access Date</source>
        <translation>Laatst bekeken</translation>
    </message>
    <message>
        <source>Last Modification Date</source>
        <translation>Laatst gewijzigd</translation>
    </message>
    <message>
        <source>Expiration Date</source>
        <translation>Vervaldatum</translation>
    </message>
    <message>
        <source>Time till Expiration</source>
        <translation>Resterende tijd</translation>
    </message>
</context>
<context>
    <name>Database</name>
    <message>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsDlg</name>
    <message>
        <source>Database Settings</source>
        <translation>Database-instellingen</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Versleuteling</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritme:</translation>
    </message>
    <message>
        <source>Encryption Rounds:</source>
        <translation>Versleutelingsiteraties:</translation>
    </message>
    <message>
        <source>Calculate rounds for a 1-second delay on this computer</source>
        <translation>Het aantal iteraties voor een vertraging 
van 1 seconde op deze computer berekenen</translation>
    </message>
</context>
<context>
    <name>DetailViewTemplate</name>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Creation</source>
        <translation>Aanmaakdatum</translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation>Laatst bekeken</translation>
    </message>
    <message>
        <source>Last Modification</source>
        <translation>Laatst gewijzigd</translation>
    </message>
    <message>
        <source>Expiration</source>
        <translation>Vervaldatum</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Notities</translation>
    </message>
</context>
<context>
    <name>EditEntryDialog</name>
    <message>
        <source>Edit Entry</source>
        <translation>Item wijzigen</translation>
    </message>
    <message>
        <source>Ge&amp;n.</source>
        <translation>Ge&amp;n.</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Veiligheidsniveau:</translation>
    </message>
    <message>
        <source>Attachment:</source>
        <translation>Bijlage:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Gebruikersnaam:</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Notities:</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>Url:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Groep:</translation>
    </message>
    <message>
        <source>Password Repet.:</source>
        <translation type="obsolete">Nogmaals:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Expires:</source>
        <translation>Vervaldatum:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation>%1 Bits</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Pictogram:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Nogmaals:</translation>
    </message>
</context>
<context>
    <name>EditGroupDialog</name>
    <message>
        <source>Group Properties</source>
        <translation>Eigenschappen van groep</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Pictogram:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
</context>
<context>
    <name>ExpiredEntriesDialog</name>
    <message>
        <source>Expired Entries</source>
        <translation>Vervallen items</translation>
    </message>
    <message>
        <source>Double click on an entry to jump to it.</source>
        <translation>Dubbelklik op een item om het te selecteren.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Expired</source>
        <translation>Vervallen</translation>
    </message>
    <message>
        <source>Expired Entries in the Database</source>
        <translation>Vervallen items in de database</translation>
    </message>
</context>
<context>
    <name>Export_KeePassX_Xml</name>
    <message>
        <source>KeePassX XML File</source>
        <translation>KeePassX XML-bestand</translation>
    </message>
    <message>
        <source>XML Files (*.xml)</source>
        <translation>XML-bestanden (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
</context>
<context>
    <name>Export_Txt</name>
    <message>
        <source>Text File</source>
        <translation>Tekstbestand</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
    <message>
        <source>Text Files (*.txt)</source>
        <translation>Tekstbestanden (*.txt)</translation>
    </message>
</context>
<context>
    <name>ExporterBase</name>
    <message>
        <source>Export Failed</source>
        <translation>Export mislukt</translation>
    </message>
    <message>
        <source>Export File...</source>
        <translation>Bestand exporteren...</translation>
    </message>
</context>
<context>
    <name>FileErrors</name>
    <message>
        <source>No error occurred.</source>
        <translation>Er is geen fout opgetreden.</translation>
    </message>
    <message>
        <source>An error occurred while reading from the file.</source>
        <translation>Er is een fout opgetreden bij het lezen van het bestand.</translation>
    </message>
    <message>
        <source>An error occurred while writing to the file.</source>
        <translation>Er is een fout opgetreden bij het schrijven naar het bestand.</translation>
    </message>
    <message>
        <source>A fatal error occurred.</source>
        <translation>Er is een onherstelbare fout opgetreden.</translation>
    </message>
    <message>
        <source>An resource error occurred.</source>
        <translation>Er is een bronfout opgetreden.</translation>
    </message>
    <message>
        <source>The file could not be opened.</source>
        <translation>Kan het bestand niet openen.</translation>
    </message>
    <message>
        <source>The operation was aborted.</source>
        <translation>De bewerking is mislukt.</translation>
    </message>
    <message>
        <source>A timeout occurred.</source>
        <translation>Er is een time-out opgetreden.</translation>
    </message>
    <message>
        <source>An unspecified error occurred.</source>
        <translation>Er is een onbekende fout opgetreden.</translation>
    </message>
    <message>
        <source>The file could not be removed.</source>
        <translation>Kan het bestand niet verwijderen.</translation>
    </message>
    <message>
        <source>The file could not be renamed.</source>
        <translation>Kan het bestand niet hernoemen.</translation>
    </message>
    <message>
        <source>The position in the file could not be changed.</source>
        <translation>Kan de positie in het bestand niet wijzigen.</translation>
    </message>
    <message>
        <source>The file could not be resized.</source>
        <translation>Kan de grootte van het bestand niet wijzigen.</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>De toegang tot het bestand is geweigerd.</translation>
    </message>
    <message>
        <source>The file could not be copied.</source>
        <translation>Kan het bestand niet kopiëren.</translation>
    </message>
</context>
<context>
    <name>GenPwDlg</name>
    <message>
        <source>Password Generator</source>
        <translation>Wachtwoordgenerator</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Use follo&amp;wing character groups:</source>
        <translation type="obsolete">Gebruik de &amp;volgende tekensets:</translation>
    </message>
    <message>
        <source>&amp;Lower Letters</source>
        <translation>K&amp;leine letters</translation>
    </message>
    <message>
        <source>&amp;Numbers</source>
        <translation>&amp;Cijfers</translation>
    </message>
    <message>
        <source>&amp;Upper Letters</source>
        <translation>&amp;Hoofdletters</translation>
    </message>
    <message>
        <source>&amp;Special Characters</source>
        <translation>&amp;Speciale tekens</translation>
    </message>
    <message>
        <source>Use &amp;only following characters:</source>
        <translation type="obsolete">Gebruik alleen de v&amp;olgende tekens:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Lengte:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Veiligheid:</translation>
    </message>
    <message>
        <source>Enable entropy collection</source>
        <translation>Entropie genereren inschakelen</translation>
    </message>
    <message>
        <source>Collect only once per session</source>
        <translation>Slechts eenmaal per sessie genereren</translation>
    </message>
    <message>
        <source>New Password:</source>
        <translation>Nieuw wachtwoord:</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>Genereren</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Willekeurig</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Li&amp;ggend streepje (underscore)</translation>
    </message>
    <message>
        <source>&amp;White Spaces</source>
        <translation>S&amp;paties</translation>
    </message>
    <message>
        <source>&amp;Minus</source>
        <translation>&amp;Minteken (-)</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Wachtwoorden met op elkaar lijkende tekens voorkomen</translation>
    </message>
    <message>
        <source>Ensure that password contains characters from every group</source>
        <translation>Wachtwoorden met tekens uit alle geselecteerde tekensets genereren</translation>
    </message>
    <message>
        <source>Pronounceable</source>
        <translation>Uitspreekbaar</translation>
    </message>
    <message>
        <source>Lower Letters</source>
        <translation>Kleine letters</translation>
    </message>
    <message>
        <source>Upper Letters</source>
        <translation>Hoofdletters</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Cijfers</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Speciale tekens</translation>
    </message>
    <message>
        <source>Use following character groups:</source>
        <translation>Gebruik de volgende tekensets:</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Op maat</translation>
    </message>
    <message>
        <source>Use the following characters:</source>
        <translation>Gebruik de volgende tekens:</translation>
    </message>
</context>
<context>
    <name>HelpDlg</name>
    <message>
        <source>Previous Page</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>Voorblad</translation>
    </message>
    <message>
        <source>Help Contents</source>
        <translation>Inhoudsopgave</translation>
    </message>
</context>
<context>
    <name>Import_KWalletXml</name>
    <message>
        <source>XML Files (*.xml)</source>
        <translation>XML-bestanden (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Import mislukt</translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation>Ongeldige XML-gegevens (zie details in stdout).</translation>
    </message>
    <message>
        <source>Invalid XML file.</source>
        <translation>Ongeldig XML-bestand.</translation>
    </message>
    <message>
        <source>Document does not contain data.</source>
        <translation>Het bestand bevat geen gegevens.</translation>
    </message>
</context>
<context>
    <name>Import_KeePassX_Xml</name>
    <message>
        <source>KeePass XML Files (*.xml)</source>
        <translation>KeePass XML-bestanden (*.xml)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Import mislukt</translation>
    </message>
    <message>
        <source>XML parsing error on line %1 column %2:
%3</source>
        <translation>XML-interpretatiefout op regel %1, kolom %2:
%3</translation>
    </message>
    <message>
        <source>Parsing error: File is no valid KeePassX XML file.</source>
        <translation>Leesfout: het bestand is geen geldig KeePassX XML-bestand.</translation>
    </message>
</context>
<context>
    <name>Import_PwManager</name>
    <message>
        <source>PwManager Files (*.pwm)</source>
        <translation>PwManager-bestanden (*.pwm)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Import mislukt</translation>
    </message>
    <message>
        <source>File is empty.</source>
        <translation>Het bestand is leeg.</translation>
    </message>
    <message>
        <source>File is no valid PwManager file.</source>
        <translation>Het bestand is geen geldig PwManager-bestand.</translation>
    </message>
    <message>
        <source>Unsupported file version.</source>
        <translation>Deze bestandsversie wordt niet ondersteund.</translation>
    </message>
    <message>
        <source>Unsupported hash algorithm.</source>
        <translation>Het hash-algoritme wordt niet ondersteund.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Het versleutelingsalgoritme wordt niet ondersteund.</translation>
    </message>
    <message>
        <source>Compressed files are not supported yet.</source>
        <translation>Gecomprimeerde bestanden worden niet ondersteund.</translation>
    </message>
    <message>
        <source>Wrong password.</source>
        <translation>Wachtwoord onjuist.</translation>
    </message>
    <message>
        <source>File is damaged (hash test failed).</source>
        <translation>Het bestand is beschadigd (hash-test mislukt).</translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation>Ongeldige XML-gegevens (zie details in stdout).</translation>
    </message>
</context>
<context>
    <name>ImporterBase</name>
    <message>
        <source>Import File...</source>
        <translation>Bestand importeren...</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation>Import mislukt</translation>
    </message>
</context>
<context>
    <name>Kdb3Database</name>
    <message>
        <source>Could not open file.</source>
        <translation>Kan bestand niet openen.</translation>
    </message>
    <message>
        <source>Unexpected file size (DB_TOTAL_SIZE &lt; DB_HEADER_SIZE)</source>
        <translation>Onverwachte bestandsgrootte (DB_TOTAL_SIZE &lt; DB_HEADER_SIZE)</translation>
    </message>
    <message>
        <source>Wrong Signature</source>
        <translation>Onjuiste ondertekening</translation>
    </message>
    <message>
        <source>Unsupported File Version.</source>
        <translation>Niet-ondersteunde bestandsversie.</translation>
    </message>
    <message>
        <source>Unknown Encryption Algorithm.</source>
        <translation>Onbekend versleutelingsalgoritme.</translation>
    </message>
    <message>
        <source>Decryption failed.
The key is wrong or the file is damaged.</source>
        <translation>Ontcijfering mislukt.
De sleutel in onjuist of het bestand is beschadigd.</translation>
    </message>
    <message>
        <source>Hash test failed.
The key is wrong or the file is damaged.</source>
        <translation>Hash-test mislukt.
De sleutel is onjuist of het bestand is beschadigd.</translation>
    </message>
    <message>
        <source>Unexpected error: Offset is out of range.</source>
        <translatorcomment>&quot;Sleuteloffset&quot; gesuggereerd in keepasx.forums.</translatorcomment>
        <translation>Onverwachte fout: Sleuteloffset is buiten bereik.</translation>
    </message>
    <message>
        <source>Invalid group tree.</source>
        <translation>Ongeldige groepenstructuur.</translation>
    </message>
    <message>
        <source>Key file is empty.</source>
        <translation>Het sleutelbestand is leeg.</translation>
    </message>
    <message>
        <source>The database must contain at least one group.</source>
        <translation>De database moet ten minste één groep bevatten.</translation>
    </message>
    <message>
        <source>Unable to initalize the twofish algorithm.</source>
        <translation type="obsolete">Kan het Twofish-algoritme niet starten.</translation>
    </message>
    <message>
        <source>The database has been opened read-only.</source>
        <translation>De database is geopend in alleen-lezen-modus.</translation>
    </message>
    <message>
        <source>Unable to initialize the twofish algorithm.</source>
        <translation>Kan het Twofish-algoritme niet starten.</translation>
    </message>
    <message>
        <source>Unknown encryption algorithm.</source>
        <translation>Onbekend versleutelingsalgoritme.</translation>
    </message>
</context>
<context>
    <name>Kdb3Database::EntryHandle</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
</context>
<context>
    <name>KeepassEntryView</name>
    <message>
        <source>Delete?</source>
        <translation>Verwijderen?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>At least one group must exist before adding an entry.</source>
        <translation>Er moet ten minste één groep bestaan voordat er een nieuw item wordt aangemaakt.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Comments</source>
        <translation>Notities</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Vervaldatum</translation>
    </message>
    <message>
        <source>Creation</source>
        <translation>Aangemaakt</translation>
    </message>
    <message>
        <source>Last Change</source>
        <translation>Laatste wijziging</translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation>Laatst bekeken</translation>
    </message>
    <message>
        <source>Attachment</source>
        <translation>Bijlage</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this entry?</source>
        <translation>Weet u zeker dat u dit item wilt verwijderen?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete these %1 entries?</source>
        <translation>Weet u zeker dat u de geselecteerde %1 items wilt verwijderen?</translation>
    </message>
</context>
<context>
    <name>KeepassGroupView</name>
    <message>
        <source>Search Results</source>
        <translation>Zoekresultaten</translation>
    </message>
    <message>
        <source>Delete?</source>
        <translation>Verwijderen?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this group, all its child groups and all their entries?</source>
        <translation>Weet u zeker dat u deze groep inclusief subgroepen en items wilt verwijderen?</translation>
    </message>
</context>
<context>
    <name>KeepassMainWindow</name>
    <message>
        <source>Ready</source>
        <translation>Gereed</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="obsolete">Vergrendeld</translation>
    </message>
    <message>
        <source>Unlocked</source>
        <translation type="obsolete">Ontgrendeld</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Shift+Ctrl+S</source>
        <translation>Shift+Ctrl+S</translation>
    </message>
    <message>
        <source>Shift+Ctrl+F</source>
        <translation>Shift+Ctrl+F</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>The database file does not exist.</source>
        <translation>Het databasebestand bestaat niet.</translation>
    </message>
    <message>
        <source>Loading Database...</source>
        <translation>Database wordt geladen...</translation>
    </message>
    <message>
        <source>Loading Failed</source>
        <translation>Laden mislukt</translation>
    </message>
    <message>
        <source>Unknown error while loading database.</source>
        <translation>Er is een onbekende fout opgetreden bij het laden van de database.</translation>
    </message>
    <message>
        <source>The following error occured while opening the database:</source>
        <translation>De volgende fout is opgetreden bij het laden van de database:</translation>
    </message>
    <message>
        <source>Save modified file?</source>
        <translation>Wilt u het gewijzigde bestand opslaan?</translation>
    </message>
    <message>
        <source>new</source>
        <translation>nieuw</translation>
    </message>
    <message>
        <source>Open Database...</source>
        <translation>Database openen...</translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation>KeePass-databases (*.kdb)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
    <message>
        <source>Expired</source>
        <translation>Vervallen</translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation>1 maand</translation>
    </message>
    <message>
        <source>%1 Months</source>
        <translation>%1 maanden</translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation>1 jaar</translation>
    </message>
    <message>
        <source>%1 Years</source>
        <translation>%1 jaren</translation>
    </message>
    <message>
        <source>1 Day</source>
        <translation>1 dag</translation>
    </message>
    <message>
        <source>%1 Days</source>
        <translation>%1 dagen</translation>
    </message>
    <message>
        <source>less than 1 day</source>
        <translation>minder dan 1 dag</translation>
    </message>
    <message>
        <source>Clone Entry</source>
        <translation>Item dupliceren</translation>
    </message>
    <message>
        <source>Delete Entry</source>
        <translation>Item verwijderen</translation>
    </message>
    <message>
        <source>Clone Entries</source>
        <translation>Items dupliceren</translation>
    </message>
    <message>
        <source>Delete Entries</source>
        <translation>Items verwijderen</translation>
    </message>
    <message>
        <source>File could not be saved.</source>
        <translation>Kan het bestand niet opslaan.</translation>
    </message>
    <message>
        <source>Save Database...</source>
        <translation>Database opslaan...</translation>
    </message>
    <message>
        <source>Un&amp;lock Workspace</source>
        <translation>Werkblad ontgrende&amp;len</translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation>Werkblad vergrende&amp;len</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>&amp;Werkbalk inschakelen</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Database locked</source>
        <translation>Database vergrendeld</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked.
This means that either someone else has opened the file or KeePassX crashed last time it opened the database.

Do you want to open it anyway?</source>
        <translation>De database die u probeert te openen is vergrendeld.
Dit betekent dat iemand anders het bestand heeft geopend of 
dat KeePassX is gecrasht toen het bestand voor het laatst is geopend.

Wilt u de database toch openen?
</translation>
    </message>
    <message>
        <source>The current file was modified.
Do you want to save the changes?</source>
        <translation>Het huidige bestand is gewijzigd.
Wilt u de wijzigingen opslaan?</translation>
    </message>
    <message>
        <source>Couldn&apos;t remove database lock file.</source>
        <translation>Het vergrendelingsbestand van de database kon niet worden verwijderd.</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation>In alleen-lezen-modus openen</translation>
    </message>
    <message>
        <source>Couldn&apos;t create lock file. Opening the database read-only.</source>
        <translation>Kan het vergrendelingsbestand van de database niet aanmaken. 
De database wordt in alleen-lezen-modus geopend.</translation>
    </message>
    <message>
        <source>Couldn&apos;t create database lock file.</source>
        <translation>Kan het vergrendelingsbestand van de database niet aanmaken.</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>vergrendeld</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation>Kan bestand &apos;%1&apos; niet vinden.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>KeePassX</source>
        <translation>KeePassX</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Groepen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;Export to...</source>
        <translation>&amp;Exporteren...</translation>
    </message>
    <message>
        <source>&amp;Import from...</source>
        <translation>&amp;Importeren...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>Beel&amp;d</translation>
    </message>
    <message>
        <source>E&amp;xtras</source>
        <translation>E&amp;xtra</translation>
    </message>
    <message>
        <source>&amp;Open Database...</source>
        <translation>Database &amp;openen...</translation>
    </message>
    <message>
        <source>&amp;Close Database</source>
        <translation>Database slui&amp;ten</translation>
    </message>
    <message>
        <source>&amp;Save Database</source>
        <translation>Database op&amp;slaan</translation>
    </message>
    <message>
        <source>Save Database &amp;As...</source>
        <translation>Database opslaan &amp;als...</translation>
    </message>
    <message>
        <source>&amp;Database Settings...</source>
        <translation>&amp;Database-instellingen...</translation>
    </message>
    <message>
        <source>Change &amp;Master Key...</source>
        <translation>&amp;Hoofdwachtwoord wijzigen...</translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation>Werkblad vergrende&amp;len</translation>
    </message>
    <message>
        <source>&amp;Settings...</source>
        <translation>&amp;Voorkeuren...</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;Over KeePassX...</translation>
    </message>
    <message>
        <source>&amp;KeePassX Handbook...</source>
        <translation>Handleiding &amp;KeePassX...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Verbergen</translation>
    </message>
    <message>
        <source>Recycle Bin...</source>
        <translation>Prullenbak...</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Favorieten</translation>
    </message>
    <message>
        <source>Toolbar &amp;Icon Size</source>
        <translation>Grootte werkbalkp&amp;ictogrammen</translation>
    </message>
    <message>
        <source>&amp;Columns</source>
        <translation>&amp;Kolommen</translation>
    </message>
    <message>
        <source>&amp;Manage Bookmarks...</source>
        <translation>&amp;Favorieten beheren...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>A&amp;fsluiten</translation>
    </message>
    <message>
        <source>&amp;Edit Group...</source>
        <translation>Gro&amp;ep wijzigen...</translation>
    </message>
    <message>
        <source>&amp;Delete Group</source>
        <translation>Groep verwij&amp;deren</translation>
    </message>
    <message>
        <source>Copy Password &amp;to Clipboard</source>
        <translation>Wach&amp;twoord naar Klembord kopiëren</translation>
    </message>
    <message>
        <source>Copy &amp;Username to Clipboard</source>
        <translation>Gebr&amp;uikersnaam naar Klembord kopiëren</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>Url &amp;openen</translation>
    </message>
    <message>
        <source>&amp;Save Attachment As...</source>
        <translation>Bijlage op&amp;slaan als...</translation>
    </message>
    <message>
        <source>Add &amp;New Entry...</source>
        <translation>&amp;Nieuw item aanmaken...</translation>
    </message>
    <message>
        <source>&amp;View/Edit Entry...</source>
        <translation>Item bekijken/&amp;wijzigen...</translation>
    </message>
    <message>
        <source>De&amp;lete Entry</source>
        <translation>Item &amp;verwijderen</translation>
    </message>
    <message>
        <source>&amp;Clone Entry</source>
        <translation>Item dupli&amp;ceren</translation>
    </message>
    <message>
        <source>Search &amp;in Database...</source>
        <translation>&amp;In de database zoeken...</translation>
    </message>
    <message>
        <source>Search in this &amp;Group...</source>
        <translation>In de geselecteerde &amp;groep zoeken...</translation>
    </message>
    <message>
        <source>Show &amp;Entry Details</source>
        <translation>D&amp;etailweergave van items inschakelen</translation>
    </message>
    <message>
        <source>Hide &amp;Usernames</source>
        <translation>Gebr&amp;uikersnamen verbergen</translation>
    </message>
    <message>
        <source>Hide &amp;Passwords</source>
        <translation>Wachtwoo&amp;rden verbergen</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>&amp;Titel</translation>
    </message>
    <message>
        <source>User&amp;name</source>
        <translation>Gebruikers&amp;naam</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>&amp;Url</translation>
    </message>
    <message>
        <source>&amp;Password</source>
        <translation>&amp;Wachtwoord</translation>
    </message>
    <message>
        <source>&amp;Comment</source>
        <translation>&amp;Notities</translation>
    </message>
    <message>
        <source>E&amp;xpires</source>
        <translation>&amp;Vervaldatum</translation>
    </message>
    <message>
        <source>C&amp;reation</source>
        <translation>Aanmaak&amp;datum</translation>
    </message>
    <message>
        <source>&amp;Last Change</source>
        <translation>&amp;Laatst gewijzigd</translation>
    </message>
    <message>
        <source>Last &amp;Access</source>
        <translation>L&amp;aatst bekeken</translation>
    </message>
    <message>
        <source>A&amp;ttachment</source>
        <translation>&amp;Bijlage</translation>
    </message>
    <message>
        <source>Show &amp;Statusbar</source>
        <translation>&amp;Statusbalk inschakelen</translation>
    </message>
    <message>
        <source>&amp;Perform AutoType</source>
        <translation>Automatisc&amp;h invullen</translation>
    </message>
    <message>
        <source>&amp;16x16</source>
        <translation>&amp;16x16</translation>
    </message>
    <message>
        <source>&amp;22x22</source>
        <translation>&amp;22x22</translation>
    </message>
    <message>
        <source>2&amp;8x28</source>
        <translation>2&amp;8x28</translation>
    </message>
    <message>
        <source>&amp;New Database...</source>
        <translation>&amp;Nieuwe database...</translation>
    </message>
    <message>
        <source>&amp;Password Generator...</source>
        <translation>&amp;Wachtwoordgenerator...</translation>
    </message>
    <message>
        <source>&amp;Group (search results only)</source>
        <translation type="obsolete">&amp;Groep (alleen zoekresultaten)</translation>
    </message>
    <message>
        <source>Show &amp;Expired Entries...</source>
        <translation>V&amp;ervallen items tonen...</translation>
    </message>
    <message>
        <source>&amp;Add Bookmark...</source>
        <translation>F&amp;avoriet toevoegen...</translation>
    </message>
    <message>
        <source>Bookmark &amp;this Database...</source>
        <translation>Da&amp;tabase aan Favorieten toevoegen...</translation>
    </message>
    <message>
        <source>&amp;Add New Subgroup...</source>
        <translation>Subgroep &amp;aanmaken...</translation>
    </message>
    <message>
        <source>Copy URL to Clipboard</source>
        <translation>Url naar Klembord kopiëren</translation>
    </message>
    <message>
        <source>Add New Group...</source>
        <translation>Nieuwe groep...</translation>
    </message>
    <message>
        <source>&amp;Entries</source>
        <translation>It&amp;ems</translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation>&amp;Groepen</translation>
    </message>
    <message>
        <source>Sort groups</source>
        <translation>Groepen sorteren</translation>
    </message>
    <message>
        <source>&amp;Group</source>
        <translation>&amp;Groep</translation>
    </message>
    <message>
        <source>&amp;Minimize Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageBookmarksDlg</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Favorieten beheren</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Enter Master Key</source>
        <translation>Voer een hoofdwachtwoord in</translation>
    </message>
    <message>
        <source>Set Master Key</source>
        <translation>Stel een hoofdwachtwoord in</translation>
    </message>
    <message>
        <source>Change Master Key</source>
        <translation>Hoofdwachtwoord wijzigen</translation>
    </message>
    <message>
        <source>Database Key</source>
        <translation>Databasewachtwoord</translation>
    </message>
    <message>
        <source>Last File</source>
        <translation>Laatste bestand</translation>
    </message>
    <message>
        <source>Select a Key File</source>
        <translation>Selecteer een sleutelbestand</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
    <message>
        <source>Key Files (*.key)</source>
        <translation>Sleutelbestanden (*.key)</translation>
    </message>
    <message>
        <source>Please enter a Password or select a key file.</source>
        <translation>Voer een wachtwoord in of selecteer een sleutelbestand.</translation>
    </message>
    <message>
        <source>Please enter a Password.</source>
        <translation>Voer een wachtwoord in.</translation>
    </message>
    <message>
        <source>Please provide a key file.</source>
        <translation>Selecteer een sleutelbestand.</translation>
    </message>
    <message>
        <source>%1:
No such file or directory.</source>
        <translation>%1:
Bestand of map niet gevonden.</translation>
    </message>
    <message>
        <source>The selected key file or directory is not readable.</source>
        <translation>Kan het geselecteerde sleutelbestand of de map niet lezen.</translation>
    </message>
    <message>
        <source>The given directory does not contain any key files.</source>
        <translation>Er zijn geen sleutelbestanden in de geselecteerde map gevonden.</translation>
    </message>
    <message>
        <source>The given directory contains more then one key files.
Please specify the key file directly.</source>
        <translation>Er zijn meerdere sleutelbestanden in deze map gevonden.
Selecteer het juiste bestand.</translation>
    </message>
    <message>
        <source>%1:
File is not readable.</source>
        <translation>%1:
Kan het bestand niet lezen.</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Sleutelbestand aanmaken...</translation>
    </message>
</context>
<context>
    <name>PasswordDlg</name>
    <message>
        <source>Last File</source>
        <translation>Laatste bestand</translation>
    </message>
    <message>
        <source>Enter a Password and/or choose a key file.</source>
        <translation>Voer een wachtwoord in en/of selecteer een sleutelbestand.</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Sleutel</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>&amp;Browse...</source>
        <translation>&amp;Bladeren...</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Sleutelbestand:</translation>
    </message>
    <message>
        <source>Generate Key File...</source>
        <translation>Sleutelbestand genereren...</translation>
    </message>
    <message>
        <source>Please repeat your password:</source>
        <translation>Voer het wachtwoord nogmaals in:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <source>Passwords are not equal.</source>
        <translation>De wachtwoorden zijn niet identiek.</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
</context>
<context>
    <name>Search_Dlg</name>
    <message>
        <source>Search...</source>
        <translation>Zoeken...</translation>
    </message>
    <message>
        <source>Include:</source>
        <translation>Zoeken in:</translation>
    </message>
    <message>
        <source>Pass&amp;words</source>
        <translation>&amp;Wachtwoorden</translation>
    </message>
    <message>
        <source>A&amp;nhang</source>
        <translation>Bijlage&amp;n</translation>
    </message>
    <message>
        <source>U&amp;RLs</source>
        <translation>U&amp;rls</translation>
    </message>
    <message>
        <source>C&amp;omments</source>
        <translation>N&amp;otities</translation>
    </message>
    <message>
        <source>&amp;Usernames</source>
        <translation>Gebr&amp;uikersnamen</translation>
    </message>
    <message>
        <source>&amp;Titles</source>
        <translation>&amp;Titels</translation>
    </message>
    <message>
        <source>&amp;Case Sensitive</source>
        <translation>&amp;Hoofdlettergevoelig</translation>
    </message>
    <message>
        <source>Regular E&amp;xpression</source>
        <translation>RegExp (Reguliere E&amp;xpressie)</translation>
    </message>
    <message>
        <source>Include Subgroups (recursive)</source>
        <translation>Ook in onderliggende groepen zoeken</translation>
    </message>
    <message>
        <source>Search For:</source>
        <translation>Zoekterm:</translation>
    </message>
</context>
<context>
    <name>SelectIconDlg</name>
    <message>
        <source>Icon Selection</source>
        <translation>Pictogram selecteren</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <source>Show system tray icon</source>
        <translation>Pictogram in systeemvak tonen</translation>
    </message>
    <message>
        <source>Minimize to tray instead of taskbar</source>
        <translation>Minimaliseren naar systeemvak in plaats van naar taakbalk</translation>
    </message>
    <message>
        <source>Minimize to tray when clicking the main window&apos;s close button</source>
        <translation type="unfinished">Minimaliseren naar systeemvak wanneer het venster wordt gesloten</translation>
    </message>
    <message>
        <source>Remember last opened file</source>
        <translation>Laatst geopende bestand onthouden</translation>
    </message>
    <message>
        <source>Remember last key type and location</source>
        <translation>Laatst gebruikte sleuteltype en -locatie onthouden</translation>
    </message>
    <message>
        <source>Start minimized</source>
        <translation>Geminimaliseerd opstarten</translation>
    </message>
    <message>
        <source>Start locked</source>
        <translation>Vergrendeld opstarten</translation>
    </message>
    <message>
        <source>Save recent directories of file dialogs</source>
        <translation>Laatst geopende mappen onthouden</translation>
    </message>
    <message>
        <source>Clear History Now</source>
        <translation>Geschiedenis wissen</translation>
    </message>
    <message>
        <source>Always ask before deleting entries or groups</source>
        <translation>Altijd om bevestiging vragen bij verwijderen van items/groepen</translation>
    </message>
    <message>
        <source>Banner Color</source>
        <translation>Kleuren van titelbalk</translation>
    </message>
    <message>
        <source>Text Color:</source>
        <translation>Tekstkleur:</translation>
    </message>
    <message>
        <source>Change...</source>
        <translation>Kiezen...</translation>
    </message>
    <message>
        <source>Color 2:</source>
        <translation>Kleur 2:</translation>
    </message>
    <message>
        <source>C&amp;hange...</source>
        <translation>&amp;Kiezen...</translation>
    </message>
    <message>
        <source>Color 1:</source>
        <translation>Kleur 1:</translation>
    </message>
    <message>
        <source>Alternating Row Colors</source>
        <translation>Wisselende achtergrondkleur voor rijen gebruiken </translation>
    </message>
    <message>
        <source>Customize Entry Detail View...</source>
        <translation>Detailweergave van items aanpassen...</translation>
    </message>
    <message>
        <source>Group tree at start-up:</source>
        <translation>Weergave van groepen bij opstarten:</translation>
    </message>
    <message>
        <source>Restore last state</source>
        <translation>Zoals bij afsluiten</translation>
    </message>
    <message>
        <source>Expand all items</source>
        <translation>Alle groepen weergeven</translation>
    </message>
    <message>
        <source>Do not expand any item</source>
        <translation>Alleen hoofdgroepen tonen</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Beveiliging</translation>
    </message>
    <message>
        <source>Edit Entry Dialog</source>
        <translation>Venster &quot;Item wijzigen&quot;</translation>
    </message>
    <message>
        <source>Clear clipboard after:</source>
        <translation>Klembord wissen na:</translation>
    </message>
    <message>
        <source>Lock workspace when minimizing the main window</source>
        <translation>Werkblad vergrendelen wanneer het venster geminimaliseerd wordt</translation>
    </message>
    <message>
        <source>You can disable several features of KeePassX here according to your needs in order to keep the user interface slim.</source>
        <translation>U kunt hier naar wens onderdelen van KeePassX uitschakelen om de toepassing een minimalistischer uiterlijk te geven.</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Favorieten</translation>
    </message>
    <message>
        <source>Plug-Ins</source>
        <translation>Plug-ins</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Gnome Desktop Integration (Gtk 2.x)</source>
        <translation>Integratie met Gnome Desktop (Gtk 2.x)</translation>
    </message>
    <message>
        <source>KDE 4 Desktop Integration</source>
        <translation>Integratie met KDE4 Desktop</translation>
    </message>
    <message>
        <source>You need to restart the program before the changes take effect.</source>
        <translation>De wijzigingen worden pas van kracht wanneer u het programma opnieuw opstart.</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Instellen...</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <source>Auto-Type Fine Tuning</source>
        <translation>Instellingen voor Automatisch Invullen</translation>
    </message>
    <message>
        <source>Time between the activation of an auto-type action by the user and the first simulated key stroke.</source>
        <translation>Tijd tussen het starten van de opdracht Automatisch Invullen en de eerste gesimuleerde toetsaanslag.</translation>
    </message>
    <message>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <source>Pre-Gap:</source>
        <translation>Wachttijd:</translation>
    </message>
    <message>
        <source>Key Stroke Delay:</source>
        <translation>Vertraging toetsaanslagen:</translation>
    </message>
    <message>
        <source>Delay between two simulated key strokes. Increase this if Auto-Type is randomly skipping characters.</source>
        <translation>Vertraging tussen twee gesimuleerde toetsaanslagen. U kunt deze waarde verhogen wanneer Automatisch Invullen soms tekens overslaat.</translation>
    </message>
    <message>
        <source>Custom Browser Command</source>
        <translation>Aangepaste browser-opdrachtregel</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <source>Media Root:</source>
        <translation>Map voor media:</translation>
    </message>
    <message>
        <source>The directory where storage devices like CDs and memory sticks are normally mounted.</source>
        <translation>De map waar opslagmedia zoals cd&apos;s en geheugenkaarten normaliter gekoppeld zijn.</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Bladeren...</translation>
    </message>
    <message>
        <source>Enable this if you want to use your bookmarks and the last opened file independet from their absolute paths. This is especially useful when using KeePassX portably and therefore with changing mount points in the file system.</source>
        <translation>Gebruik deze optie wanneer u uw favorieten en het laatst geopende bestand wilt gebruiken onafhankelijk van hun absolute pad. Dit is vooral handig wanneer KeePassX op draagbare media is geïnstalleerd waarvan het pad automatisch wordt bepaald bij aansluiting op een pc.</translation>
    </message>
    <message>
        <source>Save relative paths (bookmarks and last file)</source>
        <translation>Relatieve paden opslaan (favorieten en laatst geopend bestand)</translation>
    </message>
    <message>
        <source>Global Auto-Type Shortcut:</source>
        <translation>Globale snelkoppeling voor Automatisch Invullen:</translation>
    </message>
    <message>
        <source>Automatically save database on exit and workspace locking</source>
        <translation>Database automatisch opslaan bij werkbladvergrendeling en bij afsluiten</translation>
    </message>
    <message>
        <source>Show plain text passwords in:</source>
        <translation>Wachtwoorden leesbaar tonen in:</translation>
    </message>
    <message>
        <source>Database Key Dialog</source>
        <translation>Venster &quot;Databasesleutel&quot;</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>seconden</translation>
    </message>
    <message>
        <source>Lock database after inactivity of</source>
        <translation>Database vergrendelen als er geen activiteit is gedurende</translation>
    </message>
    <message>
        <source>Use entries&apos; title to match the window for Global Auto-Type</source>
        <translation>Kies het venster voor Automatisch Invullen op basis van de titel van het item</translation>
    </message>
    <message>
        <source>General (1)</source>
        <translation>Algemeen (1)</translation>
    </message>
    <message>
        <source>General (2)</source>
        <translation>Algemeen (2)</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Beeld</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <source>Save backups of modified entries into the &apos;Backup&apos; group</source>
        <translation>Back-ups van gewijzigde items in de groep &apos;Backup&apos; opslaan</translation>
    </message>
    <message>
        <source>Delete backup entries older than:</source>
        <translation>Back-up items verwijderen na:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dagen</translation>
    </message>
    <message>
        <source>Automatically save database after every change</source>
        <translation>Database automatisch opslaan na elke wijziging</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Taal:</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Vertaler:</translation>
    </message>
    <message>
        <source>Show window always on top</source>
        <translation>Venster altijd op de voorgrond weergeven</translation>
    </message>
</context>
<context>
    <name>ShortcutWidget</name>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>AltGr</source>
        <translation>Alt (Rechts)</translation>
    </message>
    <message>
        <source>Win</source>
        <translation>Win</translation>
    </message>
</context>
<context>
    <name>SimplePasswordDialog</name>
    <message>
        <source>Enter your Password</source>
        <translation>Voer uw wachtwoord in</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
</context>
<context>
    <name>TargetWindowDlg</name>
    <message>
        <source>Auto-Type: Select Target Window</source>
        <translation>Automatisch invullen: selecteer het doelvenster</translation>
    </message>
    <message>
        <source>To specify the target window, either select an existing currently-opened window
from the drop-down list, or enter the window title manually:</source>
        <translation>Om een doelvenster te selecteren, kiest u een van de momenteel geopende
vensters in het uitklapmenu of voert u de naam van het venster handmatig in:</translation>
    </message>
</context>
<context>
    <name>Translation</name>
    <message>
        <source>$TRANSLATION_AUTHOR</source>
        <translation>Sipke</translation>
    </message>
    <message>
        <source>$TRANSLATION_AUTHOR_EMAIL</source>
        <comment>Here you can enter your email or homepage if you want.</comment>
        <translation>sipke5r@hotmail.com</translation>
    </message>
    <message>
        <source>$LANGUAGE_NAME</source>
        <comment>Insert your language name in the format: English (United States)</comment>
        <translation>Nederlands (Nederland)</translation>
    </message>
</context>
<context>
    <name>WorkspaceLockedWidget</name>
    <message>
        <source>Form</source>
        <translation>Formulier</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;The workspace is locked.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Het Werkblad is vergrendeld.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Unlock</source>
        <translation>Ontgrendelen</translation>
    </message>
    <message>
        <source>Close Database</source>
        <translation>Database sluiten</translation>
    </message>
</context>
</TS>
